from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class Blocked(BaseModel):
    """
    types.contacts.Blocked
    ID: 0xade1591
    Layer: 181
    """
    QUALNAME: typing.Literal['types.contacts.Blocked', 'Blocked'] = pydantic.Field(
        'types.contacts.Blocked',
        alias='_'
    )

    blocked: list["base.PeerBlocked"]
    chats: list["base.Chat"]
    users: list["base.User"]
