from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetWallPaper(BaseModel):
    """
    functions.account.GetWallPaper
    ID: 0xfc8ddbea
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.account.GetWallPaper', 'GetWallPaper'] = pydantic.Field(
        'functions.account.GetWallPaper',
        alias='_'
    )

    wallpaper: "base.InputWallPaper"
