from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetDefaultProfilePhotoEmojis(BaseModel):
    """
    functions.account.GetDefaultProfilePhotoEmojis
    ID: 0xe2750328
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.account.GetDefaultProfilePhotoEmojis', 'GetDefaultProfilePhotoEmojis'] = pydantic.Field(
        'functions.account.GetDefaultProfilePhotoEmojis',
        alias='_'
    )

    hash: int
