from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class LeaveChatlist(BaseModel):
    """
    functions.chatlists.LeaveChatlist
    ID: 0x74fae13a
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.chatlists.LeaveChatlist', 'LeaveChatlist'] = pydantic.Field(
        'functions.chatlists.LeaveChatlist',
        alias='_'
    )

    chatlist: "base.InputChatlist"
    peers: list["base.InputPeer"]
