from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class WebPageEmpty(BaseModel):
    """
    types.WebPageEmpty
    ID: 0x211a1788
    Layer: 181
    """
    QUALNAME: typing.Literal['types.WebPageEmpty', 'WebPageEmpty'] = pydantic.Field(
        'types.WebPageEmpty',
        alias='_'
    )

    id: int
    url: typing.Optional[str] = None
