from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class AcceptCall(BaseModel):
    """
    functions.phone.AcceptCall
    ID: 0x3bd2b4a0
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.phone.AcceptCall', 'AcceptCall'] = pydantic.Field(
        'functions.phone.AcceptCall',
        alias='_'
    )

    peer: "base.InputPhoneCall"
    g_b: Bytes
    protocol: "base.PhoneCallProtocol"
