from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetConfig(BaseModel):
    """
    functions.help.GetConfig
    ID: 0xc4f9186b
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.help.GetConfig', 'GetConfig'] = pydantic.Field(
        'functions.help.GetConfig',
        alias='_'
    )

