from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class FolderPeer(BaseModel):
    """
    types.FolderPeer
    ID: 0xe9baa668
    Layer: 181
    """
    QUALNAME: typing.Literal['types.FolderPeer', 'FolderPeer'] = pydantic.Field(
        'types.FolderPeer',
        alias='_'
    )

    peer: "base.Peer"
    folder_id: int
