from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetFactCheck(BaseModel):
    """
    functions.messages.GetFactCheck
    ID: 0xb9cdc5ee
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.GetFactCheck', 'GetFactCheck'] = pydantic.Field(
        'functions.messages.GetFactCheck',
        alias='_'
    )

    peer: "base.InputPeer"
    msg_id: list[int]
