__version__ = '0.181.5'

from . import base
from . import types
from . import functions

types.BoolFalse.model_rebuild()
types.BoolTrue.model_rebuild()
types.Error.model_rebuild()
types.Null.model_rebuild()
types.InputPeerEmpty.model_rebuild()
types.InputPeerSelf.model_rebuild()
types.InputPeerChat.model_rebuild()
types.InputPeerUser.model_rebuild()
types.InputPeerChannel.model_rebuild()
types.InputPeerUserFromMessage.model_rebuild()
types.InputPeerChannelFromMessage.model_rebuild()
types.InputUserEmpty.model_rebuild()
types.InputUserSelf.model_rebuild()
types.InputUser.model_rebuild()
types.InputUserFromMessage.model_rebuild()
types.InputPhoneContact.model_rebuild()
types.InputFile.model_rebuild()
types.InputFileBig.model_rebuild()
types.InputMediaEmpty.model_rebuild()
types.InputMediaUploadedPhoto.model_rebuild()
types.InputMediaPhoto.model_rebuild()
types.InputMediaGeoPoint.model_rebuild()
types.InputMediaContact.model_rebuild()
types.InputMediaUploadedDocument.model_rebuild()
types.InputMediaDocument.model_rebuild()
types.InputMediaVenue.model_rebuild()
types.InputMediaPhotoExternal.model_rebuild()
types.InputMediaDocumentExternal.model_rebuild()
types.InputMediaGame.model_rebuild()
types.InputMediaInvoice.model_rebuild()
types.InputMediaGeoLive.model_rebuild()
types.InputMediaPoll.model_rebuild()
types.InputMediaDice.model_rebuild()
types.InputMediaStory.model_rebuild()
types.InputMediaWebPage.model_rebuild()
types.InputChatPhotoEmpty.model_rebuild()
types.InputChatUploadedPhoto.model_rebuild()
types.InputChatPhoto.model_rebuild()
types.InputGeoPointEmpty.model_rebuild()
types.InputGeoPoint.model_rebuild()
types.InputPhotoEmpty.model_rebuild()
types.InputPhoto.model_rebuild()
types.InputFileLocation.model_rebuild()
types.InputEncryptedFileLocation.model_rebuild()
types.InputDocumentFileLocation.model_rebuild()
types.InputSecureFileLocation.model_rebuild()
types.InputTakeoutFileLocation.model_rebuild()
types.InputPhotoFileLocation.model_rebuild()
types.InputPhotoLegacyFileLocation.model_rebuild()
types.InputPeerPhotoFileLocation.model_rebuild()
types.InputStickerSetThumb.model_rebuild()
types.InputGroupCallStream.model_rebuild()
types.PeerUser.model_rebuild()
types.PeerChat.model_rebuild()
types.PeerChannel.model_rebuild()
types.UserEmpty.model_rebuild()
types.User.model_rebuild()
types.UserProfilePhotoEmpty.model_rebuild()
types.UserProfilePhoto.model_rebuild()
types.UserStatusEmpty.model_rebuild()
types.UserStatusOnline.model_rebuild()
types.UserStatusOffline.model_rebuild()
types.UserStatusRecently.model_rebuild()
types.UserStatusLastWeek.model_rebuild()
types.UserStatusLastMonth.model_rebuild()
types.ChatEmpty.model_rebuild()
types.Chat.model_rebuild()
types.ChatForbidden.model_rebuild()
types.Channel.model_rebuild()
types.ChannelForbidden.model_rebuild()
types.ChatFull.model_rebuild()
types.ChannelFull.model_rebuild()
types.ChatParticipant.model_rebuild()
types.ChatParticipantCreator.model_rebuild()
types.ChatParticipantAdmin.model_rebuild()
types.ChatParticipantsForbidden.model_rebuild()
types.ChatParticipants.model_rebuild()
types.ChatPhotoEmpty.model_rebuild()
types.ChatPhoto.model_rebuild()
types.MessageEmpty.model_rebuild()
types.Message.model_rebuild()
types.MessageService.model_rebuild()
types.MessageMediaEmpty.model_rebuild()
types.MessageMediaPhoto.model_rebuild()
types.MessageMediaGeo.model_rebuild()
types.MessageMediaContact.model_rebuild()
types.MessageMediaUnsupported.model_rebuild()
types.MessageMediaDocument.model_rebuild()
types.MessageMediaWebPage.model_rebuild()
types.MessageMediaVenue.model_rebuild()
types.MessageMediaGame.model_rebuild()
types.MessageMediaInvoice.model_rebuild()
types.MessageMediaGeoLive.model_rebuild()
types.MessageMediaPoll.model_rebuild()
types.MessageMediaDice.model_rebuild()
types.MessageMediaStory.model_rebuild()
types.MessageMediaGiveaway.model_rebuild()
types.MessageMediaGiveawayResults.model_rebuild()
types.MessageActionEmpty.model_rebuild()
types.MessageActionChatCreate.model_rebuild()
types.MessageActionChatEditTitle.model_rebuild()
types.MessageActionChatEditPhoto.model_rebuild()
types.MessageActionChatDeletePhoto.model_rebuild()
types.MessageActionChatAddUser.model_rebuild()
types.MessageActionChatDeleteUser.model_rebuild()
types.MessageActionChatJoinedByLink.model_rebuild()
types.MessageActionChannelCreate.model_rebuild()
types.MessageActionChatMigrateTo.model_rebuild()
types.MessageActionChannelMigrateFrom.model_rebuild()
types.MessageActionPinMessage.model_rebuild()
types.MessageActionHistoryClear.model_rebuild()
types.MessageActionGameScore.model_rebuild()
types.MessageActionPaymentSentMe.model_rebuild()
types.MessageActionPaymentSent.model_rebuild()
types.MessageActionPhoneCall.model_rebuild()
types.MessageActionScreenshotTaken.model_rebuild()
types.MessageActionCustomAction.model_rebuild()
types.MessageActionBotAllowed.model_rebuild()
types.MessageActionSecureValuesSentMe.model_rebuild()
types.MessageActionSecureValuesSent.model_rebuild()
types.MessageActionContactSignUp.model_rebuild()
types.MessageActionGeoProximityReached.model_rebuild()
types.MessageActionGroupCall.model_rebuild()
types.MessageActionInviteToGroupCall.model_rebuild()
types.MessageActionSetMessagesTTL.model_rebuild()
types.MessageActionGroupCallScheduled.model_rebuild()
types.MessageActionSetChatTheme.model_rebuild()
types.MessageActionChatJoinedByRequest.model_rebuild()
types.MessageActionWebViewDataSentMe.model_rebuild()
types.MessageActionWebViewDataSent.model_rebuild()
types.MessageActionGiftPremium.model_rebuild()
types.MessageActionTopicCreate.model_rebuild()
types.MessageActionTopicEdit.model_rebuild()
types.MessageActionSuggestProfilePhoto.model_rebuild()
types.MessageActionRequestedPeer.model_rebuild()
types.MessageActionSetChatWallPaper.model_rebuild()
types.MessageActionGiftCode.model_rebuild()
types.MessageActionGiveawayLaunch.model_rebuild()
types.MessageActionGiveawayResults.model_rebuild()
types.MessageActionBoostApply.model_rebuild()
types.MessageActionRequestedPeerSentMe.model_rebuild()
types.Dialog.model_rebuild()
types.DialogFolder.model_rebuild()
types.PhotoEmpty.model_rebuild()
types.Photo.model_rebuild()
types.PhotoSizeEmpty.model_rebuild()
types.PhotoSize.model_rebuild()
types.PhotoCachedSize.model_rebuild()
types.PhotoStrippedSize.model_rebuild()
types.PhotoSizeProgressive.model_rebuild()
types.PhotoPathSize.model_rebuild()
types.GeoPointEmpty.model_rebuild()
types.GeoPoint.model_rebuild()
types.InputNotifyPeer.model_rebuild()
types.InputNotifyUsers.model_rebuild()
types.InputNotifyChats.model_rebuild()
types.InputNotifyBroadcasts.model_rebuild()
types.InputNotifyForumTopic.model_rebuild()
types.InputPeerNotifySettings.model_rebuild()
types.PeerNotifySettings.model_rebuild()
types.PeerSettings.model_rebuild()
types.WallPaper.model_rebuild()
types.WallPaperNoFile.model_rebuild()
types.InputReportReasonSpam.model_rebuild()
types.InputReportReasonViolence.model_rebuild()
types.InputReportReasonPornography.model_rebuild()
types.InputReportReasonChildAbuse.model_rebuild()
types.InputReportReasonOther.model_rebuild()
types.InputReportReasonCopyright.model_rebuild()
types.InputReportReasonGeoIrrelevant.model_rebuild()
types.InputReportReasonFake.model_rebuild()
types.InputReportReasonIllegalDrugs.model_rebuild()
types.InputReportReasonPersonalDetails.model_rebuild()
types.UserFull.model_rebuild()
types.Contact.model_rebuild()
types.ImportedContact.model_rebuild()
types.ContactStatus.model_rebuild()
types.InputMessagesFilterEmpty.model_rebuild()
types.InputMessagesFilterPhotos.model_rebuild()
types.InputMessagesFilterVideo.model_rebuild()
types.InputMessagesFilterPhotoVideo.model_rebuild()
types.InputMessagesFilterDocument.model_rebuild()
types.InputMessagesFilterUrl.model_rebuild()
types.InputMessagesFilterGif.model_rebuild()
types.InputMessagesFilterVoice.model_rebuild()
types.InputMessagesFilterMusic.model_rebuild()
types.InputMessagesFilterChatPhotos.model_rebuild()
types.InputMessagesFilterPhoneCalls.model_rebuild()
types.InputMessagesFilterRoundVoice.model_rebuild()
types.InputMessagesFilterRoundVideo.model_rebuild()
types.InputMessagesFilterMyMentions.model_rebuild()
types.InputMessagesFilterGeo.model_rebuild()
types.InputMessagesFilterContacts.model_rebuild()
types.InputMessagesFilterPinned.model_rebuild()
types.UpdateNewMessage.model_rebuild()
types.UpdateMessageID.model_rebuild()
types.UpdateDeleteMessages.model_rebuild()
types.UpdateUserTyping.model_rebuild()
types.UpdateChatUserTyping.model_rebuild()
types.UpdateChatParticipants.model_rebuild()
types.UpdateUserStatus.model_rebuild()
types.UpdateUserName.model_rebuild()
types.UpdateNewAuthorization.model_rebuild()
types.UpdateNewEncryptedMessage.model_rebuild()
types.UpdateEncryptedChatTyping.model_rebuild()
types.UpdateEncryption.model_rebuild()
types.UpdateEncryptedMessagesRead.model_rebuild()
types.UpdateChatParticipantAdd.model_rebuild()
types.UpdateChatParticipantDelete.model_rebuild()
types.UpdateDcOptions.model_rebuild()
types.UpdateNotifySettings.model_rebuild()
types.UpdateServiceNotification.model_rebuild()
types.UpdatePrivacy.model_rebuild()
types.UpdateUserPhone.model_rebuild()
types.UpdateReadHistoryInbox.model_rebuild()
types.UpdateReadHistoryOutbox.model_rebuild()
types.UpdateWebPage.model_rebuild()
types.UpdateReadMessagesContents.model_rebuild()
types.UpdateChannelTooLong.model_rebuild()
types.UpdateChannel.model_rebuild()
types.UpdateNewChannelMessage.model_rebuild()
types.UpdateReadChannelInbox.model_rebuild()
types.UpdateDeleteChannelMessages.model_rebuild()
types.UpdateChannelMessageViews.model_rebuild()
types.UpdateChatParticipantAdmin.model_rebuild()
types.UpdateNewStickerSet.model_rebuild()
types.UpdateStickerSetsOrder.model_rebuild()
types.UpdateStickerSets.model_rebuild()
types.UpdateSavedGifs.model_rebuild()
types.UpdateBotInlineQuery.model_rebuild()
types.UpdateBotInlineSend.model_rebuild()
types.UpdateEditChannelMessage.model_rebuild()
types.UpdateBotCallbackQuery.model_rebuild()
types.UpdateEditMessage.model_rebuild()
types.UpdateInlineBotCallbackQuery.model_rebuild()
types.UpdateReadChannelOutbox.model_rebuild()
types.UpdateDraftMessage.model_rebuild()
types.UpdateReadFeaturedStickers.model_rebuild()
types.UpdateRecentStickers.model_rebuild()
types.UpdateConfig.model_rebuild()
types.UpdatePtsChanged.model_rebuild()
types.UpdateChannelWebPage.model_rebuild()
types.UpdateDialogPinned.model_rebuild()
types.UpdatePinnedDialogs.model_rebuild()
types.UpdateBotWebhookJSON.model_rebuild()
types.UpdateBotWebhookJSONQuery.model_rebuild()
types.UpdateBotShippingQuery.model_rebuild()
types.UpdateBotPrecheckoutQuery.model_rebuild()
types.UpdatePhoneCall.model_rebuild()
types.UpdateLangPackTooLong.model_rebuild()
types.UpdateLangPack.model_rebuild()
types.UpdateFavedStickers.model_rebuild()
types.UpdateChannelReadMessagesContents.model_rebuild()
types.UpdateContactsReset.model_rebuild()
types.UpdateChannelAvailableMessages.model_rebuild()
types.UpdateDialogUnreadMark.model_rebuild()
types.UpdateMessagePoll.model_rebuild()
types.UpdateChatDefaultBannedRights.model_rebuild()
types.UpdateFolderPeers.model_rebuild()
types.UpdatePeerSettings.model_rebuild()
types.UpdatePeerLocated.model_rebuild()
types.UpdateNewScheduledMessage.model_rebuild()
types.UpdateDeleteScheduledMessages.model_rebuild()
types.UpdateTheme.model_rebuild()
types.UpdateGeoLiveViewed.model_rebuild()
types.UpdateLoginToken.model_rebuild()
types.UpdateMessagePollVote.model_rebuild()
types.UpdateDialogFilter.model_rebuild()
types.UpdateDialogFilterOrder.model_rebuild()
types.UpdateDialogFilters.model_rebuild()
types.UpdatePhoneCallSignalingData.model_rebuild()
types.UpdateChannelMessageForwards.model_rebuild()
types.UpdateReadChannelDiscussionInbox.model_rebuild()
types.UpdateReadChannelDiscussionOutbox.model_rebuild()
types.UpdatePeerBlocked.model_rebuild()
types.UpdateChannelUserTyping.model_rebuild()
types.UpdatePinnedMessages.model_rebuild()
types.UpdatePinnedChannelMessages.model_rebuild()
types.UpdateChat.model_rebuild()
types.UpdateGroupCallParticipants.model_rebuild()
types.UpdateGroupCall.model_rebuild()
types.UpdatePeerHistoryTTL.model_rebuild()
types.UpdateChatParticipant.model_rebuild()
types.UpdateChannelParticipant.model_rebuild()
types.UpdateBotStopped.model_rebuild()
types.UpdateGroupCallConnection.model_rebuild()
types.UpdateBotCommands.model_rebuild()
types.UpdatePendingJoinRequests.model_rebuild()
types.UpdateBotChatInviteRequester.model_rebuild()
types.UpdateMessageReactions.model_rebuild()
types.UpdateAttachMenuBots.model_rebuild()
types.UpdateWebViewResultSent.model_rebuild()
types.UpdateBotMenuButton.model_rebuild()
types.UpdateSavedRingtones.model_rebuild()
types.UpdateTranscribedAudio.model_rebuild()
types.UpdateReadFeaturedEmojiStickers.model_rebuild()
types.UpdateUserEmojiStatus.model_rebuild()
types.UpdateRecentEmojiStatuses.model_rebuild()
types.UpdateRecentReactions.model_rebuild()
types.UpdateMoveStickerSetToTop.model_rebuild()
types.UpdateMessageExtendedMedia.model_rebuild()
types.UpdateChannelPinnedTopic.model_rebuild()
types.UpdateChannelPinnedTopics.model_rebuild()
types.UpdateUser.model_rebuild()
types.UpdateAutoSaveSettings.model_rebuild()
types.UpdateStory.model_rebuild()
types.UpdateReadStories.model_rebuild()
types.UpdateStoryID.model_rebuild()
types.UpdateStoriesStealthMode.model_rebuild()
types.UpdateSentStoryReaction.model_rebuild()
types.UpdateBotChatBoost.model_rebuild()
types.UpdateChannelViewForumAsMessages.model_rebuild()
types.UpdatePeerWallpaper.model_rebuild()
types.UpdateBotMessageReaction.model_rebuild()
types.UpdateBotMessageReactions.model_rebuild()
types.UpdateSavedDialogPinned.model_rebuild()
types.UpdatePinnedSavedDialogs.model_rebuild()
types.UpdateSavedReactionTags.model_rebuild()
types.UpdateSmsJob.model_rebuild()
types.UpdateQuickReplies.model_rebuild()
types.UpdateNewQuickReply.model_rebuild()
types.UpdateDeleteQuickReply.model_rebuild()
types.UpdateQuickReplyMessage.model_rebuild()
types.UpdateDeleteQuickReplyMessages.model_rebuild()
types.UpdateBotBusinessConnect.model_rebuild()
types.UpdateBotNewBusinessMessage.model_rebuild()
types.UpdateBotEditBusinessMessage.model_rebuild()
types.UpdateBotDeleteBusinessMessage.model_rebuild()
types.UpdateNewStoryReaction.model_rebuild()
types.UpdateBroadcastRevenueTransactions.model_rebuild()
types.UpdateStarsBalance.model_rebuild()
types.UpdatesTooLong.model_rebuild()
types.UpdateShortMessage.model_rebuild()
types.UpdateShortChatMessage.model_rebuild()
types.UpdateShort.model_rebuild()
types.UpdatesCombined.model_rebuild()
types.Updates.model_rebuild()
types.UpdateShortSentMessage.model_rebuild()
types.DcOption.model_rebuild()
types.Config.model_rebuild()
types.NearestDc.model_rebuild()
types.EncryptedChatEmpty.model_rebuild()
types.EncryptedChatWaiting.model_rebuild()
types.EncryptedChatRequested.model_rebuild()
types.EncryptedChat.model_rebuild()
types.EncryptedChatDiscarded.model_rebuild()
types.InputEncryptedChat.model_rebuild()
types.EncryptedFileEmpty.model_rebuild()
types.EncryptedFile.model_rebuild()
types.InputEncryptedFileEmpty.model_rebuild()
types.InputEncryptedFileUploaded.model_rebuild()
types.InputEncryptedFile.model_rebuild()
types.InputEncryptedFileBigUploaded.model_rebuild()
types.EncryptedMessage.model_rebuild()
types.EncryptedMessageService.model_rebuild()
types.InputDocumentEmpty.model_rebuild()
types.InputDocument.model_rebuild()
types.DocumentEmpty.model_rebuild()
types.Document.model_rebuild()
types.NotifyPeer.model_rebuild()
types.NotifyUsers.model_rebuild()
types.NotifyChats.model_rebuild()
types.NotifyBroadcasts.model_rebuild()
types.NotifyForumTopic.model_rebuild()
types.SendMessageTypingAction.model_rebuild()
types.SendMessageCancelAction.model_rebuild()
types.SendMessageRecordVideoAction.model_rebuild()
types.SendMessageUploadVideoAction.model_rebuild()
types.SendMessageRecordAudioAction.model_rebuild()
types.SendMessageUploadAudioAction.model_rebuild()
types.SendMessageUploadPhotoAction.model_rebuild()
types.SendMessageUploadDocumentAction.model_rebuild()
types.SendMessageGeoLocationAction.model_rebuild()
types.SendMessageChooseContactAction.model_rebuild()
types.SendMessageGamePlayAction.model_rebuild()
types.SendMessageRecordRoundAction.model_rebuild()
types.SendMessageUploadRoundAction.model_rebuild()
types.SpeakingInGroupCallAction.model_rebuild()
types.SendMessageHistoryImportAction.model_rebuild()
types.SendMessageChooseStickerAction.model_rebuild()
types.SendMessageEmojiInteraction.model_rebuild()
types.SendMessageEmojiInteractionSeen.model_rebuild()
types.InputPrivacyKeyStatusTimestamp.model_rebuild()
types.InputPrivacyKeyChatInvite.model_rebuild()
types.InputPrivacyKeyPhoneCall.model_rebuild()
types.InputPrivacyKeyPhoneP2P.model_rebuild()
types.InputPrivacyKeyForwards.model_rebuild()
types.InputPrivacyKeyProfilePhoto.model_rebuild()
types.InputPrivacyKeyPhoneNumber.model_rebuild()
types.InputPrivacyKeyAddedByPhone.model_rebuild()
types.InputPrivacyKeyVoiceMessages.model_rebuild()
types.InputPrivacyKeyAbout.model_rebuild()
types.InputPrivacyKeyBirthday.model_rebuild()
types.PrivacyKeyStatusTimestamp.model_rebuild()
types.PrivacyKeyChatInvite.model_rebuild()
types.PrivacyKeyPhoneCall.model_rebuild()
types.PrivacyKeyPhoneP2P.model_rebuild()
types.PrivacyKeyForwards.model_rebuild()
types.PrivacyKeyProfilePhoto.model_rebuild()
types.PrivacyKeyPhoneNumber.model_rebuild()
types.PrivacyKeyAddedByPhone.model_rebuild()
types.PrivacyKeyVoiceMessages.model_rebuild()
types.PrivacyKeyAbout.model_rebuild()
types.PrivacyKeyBirthday.model_rebuild()
types.InputPrivacyValueAllowContacts.model_rebuild()
types.InputPrivacyValueAllowAll.model_rebuild()
types.InputPrivacyValueAllowUsers.model_rebuild()
types.InputPrivacyValueDisallowContacts.model_rebuild()
types.InputPrivacyValueDisallowAll.model_rebuild()
types.InputPrivacyValueDisallowUsers.model_rebuild()
types.InputPrivacyValueAllowChatParticipants.model_rebuild()
types.InputPrivacyValueDisallowChatParticipants.model_rebuild()
types.InputPrivacyValueAllowCloseFriends.model_rebuild()
types.InputPrivacyValueAllowPremium.model_rebuild()
types.PrivacyValueAllowContacts.model_rebuild()
types.PrivacyValueAllowAll.model_rebuild()
types.PrivacyValueAllowUsers.model_rebuild()
types.PrivacyValueDisallowContacts.model_rebuild()
types.PrivacyValueDisallowAll.model_rebuild()
types.PrivacyValueDisallowUsers.model_rebuild()
types.PrivacyValueAllowChatParticipants.model_rebuild()
types.PrivacyValueDisallowChatParticipants.model_rebuild()
types.PrivacyValueAllowCloseFriends.model_rebuild()
types.PrivacyValueAllowPremium.model_rebuild()
types.AccountDaysTTL.model_rebuild()
types.DocumentAttributeImageSize.model_rebuild()
types.DocumentAttributeAnimated.model_rebuild()
types.DocumentAttributeSticker.model_rebuild()
types.DocumentAttributeVideo.model_rebuild()
types.DocumentAttributeAudio.model_rebuild()
types.DocumentAttributeFilename.model_rebuild()
types.DocumentAttributeHasStickers.model_rebuild()
types.DocumentAttributeCustomEmoji.model_rebuild()
types.StickerPack.model_rebuild()
types.WebPageEmpty.model_rebuild()
types.WebPagePending.model_rebuild()
types.WebPage.model_rebuild()
types.WebPageNotModified.model_rebuild()
types.Authorization.model_rebuild()
types.ReceivedNotifyMessage.model_rebuild()
types.ChatInviteExported.model_rebuild()
types.ChatInvitePublicJoinRequests.model_rebuild()
types.ChatInviteAlready.model_rebuild()
types.ChatInvite.model_rebuild()
types.ChatInvitePeek.model_rebuild()
types.InputStickerSetEmpty.model_rebuild()
types.InputStickerSetID.model_rebuild()
types.InputStickerSetShortName.model_rebuild()
types.InputStickerSetAnimatedEmoji.model_rebuild()
types.InputStickerSetDice.model_rebuild()
types.InputStickerSetAnimatedEmojiAnimations.model_rebuild()
types.InputStickerSetPremiumGifts.model_rebuild()
types.InputStickerSetEmojiGenericAnimations.model_rebuild()
types.InputStickerSetEmojiDefaultStatuses.model_rebuild()
types.InputStickerSetEmojiDefaultTopicIcons.model_rebuild()
types.InputStickerSetEmojiChannelDefaultStatuses.model_rebuild()
types.StickerSet.model_rebuild()
types.BotCommand.model_rebuild()
types.BotInfo.model_rebuild()
types.KeyboardButton.model_rebuild()
types.KeyboardButtonUrl.model_rebuild()
types.KeyboardButtonCallback.model_rebuild()
types.KeyboardButtonRequestPhone.model_rebuild()
types.KeyboardButtonRequestGeoLocation.model_rebuild()
types.KeyboardButtonSwitchInline.model_rebuild()
types.KeyboardButtonGame.model_rebuild()
types.KeyboardButtonBuy.model_rebuild()
types.KeyboardButtonUrlAuth.model_rebuild()
types.InputKeyboardButtonUrlAuth.model_rebuild()
types.KeyboardButtonRequestPoll.model_rebuild()
types.InputKeyboardButtonUserProfile.model_rebuild()
types.KeyboardButtonUserProfile.model_rebuild()
types.KeyboardButtonWebView.model_rebuild()
types.KeyboardButtonSimpleWebView.model_rebuild()
types.KeyboardButtonRequestPeer.model_rebuild()
types.InputKeyboardButtonRequestPeer.model_rebuild()
types.KeyboardButtonRow.model_rebuild()
types.ReplyKeyboardHide.model_rebuild()
types.ReplyKeyboardForceReply.model_rebuild()
types.ReplyKeyboardMarkup.model_rebuild()
types.ReplyInlineMarkup.model_rebuild()
types.MessageEntityUnknown.model_rebuild()
types.MessageEntityMention.model_rebuild()
types.MessageEntityHashtag.model_rebuild()
types.MessageEntityBotCommand.model_rebuild()
types.MessageEntityUrl.model_rebuild()
types.MessageEntityEmail.model_rebuild()
types.MessageEntityBold.model_rebuild()
types.MessageEntityItalic.model_rebuild()
types.MessageEntityCode.model_rebuild()
types.MessageEntityPre.model_rebuild()
types.MessageEntityTextUrl.model_rebuild()
types.MessageEntityMentionName.model_rebuild()
types.InputMessageEntityMentionName.model_rebuild()
types.MessageEntityPhone.model_rebuild()
types.MessageEntityCashtag.model_rebuild()
types.MessageEntityUnderline.model_rebuild()
types.MessageEntityStrike.model_rebuild()
types.MessageEntityBankCard.model_rebuild()
types.MessageEntitySpoiler.model_rebuild()
types.MessageEntityCustomEmoji.model_rebuild()
types.MessageEntityBlockquote.model_rebuild()
types.InputChannelEmpty.model_rebuild()
types.InputChannel.model_rebuild()
types.InputChannelFromMessage.model_rebuild()
types.MessageRange.model_rebuild()
types.ChannelMessagesFilterEmpty.model_rebuild()
types.ChannelMessagesFilter.model_rebuild()
types.ChannelParticipant.model_rebuild()
types.ChannelParticipantSelf.model_rebuild()
types.ChannelParticipantCreator.model_rebuild()
types.ChannelParticipantAdmin.model_rebuild()
types.ChannelParticipantBanned.model_rebuild()
types.ChannelParticipantLeft.model_rebuild()
types.ChannelParticipantsRecent.model_rebuild()
types.ChannelParticipantsAdmins.model_rebuild()
types.ChannelParticipantsKicked.model_rebuild()
types.ChannelParticipantsBots.model_rebuild()
types.ChannelParticipantsBanned.model_rebuild()
types.ChannelParticipantsSearch.model_rebuild()
types.ChannelParticipantsContacts.model_rebuild()
types.ChannelParticipantsMentions.model_rebuild()
types.InputBotInlineMessageMediaAuto.model_rebuild()
types.InputBotInlineMessageText.model_rebuild()
types.InputBotInlineMessageMediaGeo.model_rebuild()
types.InputBotInlineMessageMediaVenue.model_rebuild()
types.InputBotInlineMessageMediaContact.model_rebuild()
types.InputBotInlineMessageGame.model_rebuild()
types.InputBotInlineMessageMediaInvoice.model_rebuild()
types.InputBotInlineMessageMediaWebPage.model_rebuild()
types.InputBotInlineResult.model_rebuild()
types.InputBotInlineResultPhoto.model_rebuild()
types.InputBotInlineResultDocument.model_rebuild()
types.InputBotInlineResultGame.model_rebuild()
types.BotInlineMessageMediaAuto.model_rebuild()
types.BotInlineMessageText.model_rebuild()
types.BotInlineMessageMediaGeo.model_rebuild()
types.BotInlineMessageMediaVenue.model_rebuild()
types.BotInlineMessageMediaContact.model_rebuild()
types.BotInlineMessageMediaInvoice.model_rebuild()
types.BotInlineMessageMediaWebPage.model_rebuild()
types.BotInlineResult.model_rebuild()
types.BotInlineMediaResult.model_rebuild()
types.ExportedMessageLink.model_rebuild()
types.MessageFwdHeader.model_rebuild()
types.InputBotInlineMessageID.model_rebuild()
types.InputBotInlineMessageID64.model_rebuild()
types.InlineBotSwitchPM.model_rebuild()
types.TopPeer.model_rebuild()
types.TopPeerCategoryBotsPM.model_rebuild()
types.TopPeerCategoryBotsInline.model_rebuild()
types.TopPeerCategoryCorrespondents.model_rebuild()
types.TopPeerCategoryGroups.model_rebuild()
types.TopPeerCategoryChannels.model_rebuild()
types.TopPeerCategoryPhoneCalls.model_rebuild()
types.TopPeerCategoryForwardUsers.model_rebuild()
types.TopPeerCategoryForwardChats.model_rebuild()
types.TopPeerCategoryPeers.model_rebuild()
types.DraftMessageEmpty.model_rebuild()
types.DraftMessage.model_rebuild()
types.StickerSetCovered.model_rebuild()
types.StickerSetMultiCovered.model_rebuild()
types.StickerSetFullCovered.model_rebuild()
types.StickerSetNoCovered.model_rebuild()
types.MaskCoords.model_rebuild()
types.InputStickeredMediaPhoto.model_rebuild()
types.InputStickeredMediaDocument.model_rebuild()
types.Game.model_rebuild()
types.InputGameID.model_rebuild()
types.InputGameShortName.model_rebuild()
types.HighScore.model_rebuild()
types.TextEmpty.model_rebuild()
types.TextPlain.model_rebuild()
types.TextBold.model_rebuild()
types.TextItalic.model_rebuild()
types.TextUnderline.model_rebuild()
types.TextStrike.model_rebuild()
types.TextFixed.model_rebuild()
types.TextUrl.model_rebuild()
types.TextEmail.model_rebuild()
types.TextConcat.model_rebuild()
types.TextSubscript.model_rebuild()
types.TextSuperscript.model_rebuild()
types.TextMarked.model_rebuild()
types.TextPhone.model_rebuild()
types.TextImage.model_rebuild()
types.TextAnchor.model_rebuild()
types.PageBlockUnsupported.model_rebuild()
types.PageBlockTitle.model_rebuild()
types.PageBlockSubtitle.model_rebuild()
types.PageBlockAuthorDate.model_rebuild()
types.PageBlockHeader.model_rebuild()
types.PageBlockSubheader.model_rebuild()
types.PageBlockParagraph.model_rebuild()
types.PageBlockPreformatted.model_rebuild()
types.PageBlockFooter.model_rebuild()
types.PageBlockDivider.model_rebuild()
types.PageBlockAnchor.model_rebuild()
types.PageBlockList.model_rebuild()
types.PageBlockBlockquote.model_rebuild()
types.PageBlockPullquote.model_rebuild()
types.PageBlockPhoto.model_rebuild()
types.PageBlockVideo.model_rebuild()
types.PageBlockCover.model_rebuild()
types.PageBlockEmbed.model_rebuild()
types.PageBlockEmbedPost.model_rebuild()
types.PageBlockCollage.model_rebuild()
types.PageBlockSlideshow.model_rebuild()
types.PageBlockChannel.model_rebuild()
types.PageBlockAudio.model_rebuild()
types.PageBlockKicker.model_rebuild()
types.PageBlockTable.model_rebuild()
types.PageBlockOrderedList.model_rebuild()
types.PageBlockDetails.model_rebuild()
types.PageBlockRelatedArticles.model_rebuild()
types.PageBlockMap.model_rebuild()
types.PhoneCallDiscardReasonMissed.model_rebuild()
types.PhoneCallDiscardReasonDisconnect.model_rebuild()
types.PhoneCallDiscardReasonHangup.model_rebuild()
types.PhoneCallDiscardReasonBusy.model_rebuild()
types.DataJSON.model_rebuild()
types.LabeledPrice.model_rebuild()
types.Invoice.model_rebuild()
types.PaymentCharge.model_rebuild()
types.PostAddress.model_rebuild()
types.PaymentRequestedInfo.model_rebuild()
types.PaymentSavedCredentialsCard.model_rebuild()
types.WebDocument.model_rebuild()
types.WebDocumentNoProxy.model_rebuild()
types.InputWebDocument.model_rebuild()
types.InputWebFileLocation.model_rebuild()
types.InputWebFileGeoPointLocation.model_rebuild()
types.InputWebFileAudioAlbumThumbLocation.model_rebuild()
types.InputPaymentCredentialsSaved.model_rebuild()
types.InputPaymentCredentials.model_rebuild()
types.InputPaymentCredentialsApplePay.model_rebuild()
types.InputPaymentCredentialsGooglePay.model_rebuild()
types.ShippingOption.model_rebuild()
types.InputStickerSetItem.model_rebuild()
types.InputPhoneCall.model_rebuild()
types.PhoneCallEmpty.model_rebuild()
types.PhoneCallWaiting.model_rebuild()
types.PhoneCallRequested.model_rebuild()
types.PhoneCallAccepted.model_rebuild()
types.PhoneCall.model_rebuild()
types.PhoneCallDiscarded.model_rebuild()
types.PhoneConnection.model_rebuild()
types.PhoneConnectionWebrtc.model_rebuild()
types.PhoneCallProtocol.model_rebuild()
types.CdnPublicKey.model_rebuild()
types.CdnConfig.model_rebuild()
types.LangPackString.model_rebuild()
types.LangPackStringPluralized.model_rebuild()
types.LangPackStringDeleted.model_rebuild()
types.LangPackDifference.model_rebuild()
types.LangPackLanguage.model_rebuild()
types.ChannelAdminLogEventActionChangeTitle.model_rebuild()
types.ChannelAdminLogEventActionChangeAbout.model_rebuild()
types.ChannelAdminLogEventActionChangeUsername.model_rebuild()
types.ChannelAdminLogEventActionChangePhoto.model_rebuild()
types.ChannelAdminLogEventActionToggleInvites.model_rebuild()
types.ChannelAdminLogEventActionToggleSignatures.model_rebuild()
types.ChannelAdminLogEventActionUpdatePinned.model_rebuild()
types.ChannelAdminLogEventActionEditMessage.model_rebuild()
types.ChannelAdminLogEventActionDeleteMessage.model_rebuild()
types.ChannelAdminLogEventActionParticipantJoin.model_rebuild()
types.ChannelAdminLogEventActionParticipantLeave.model_rebuild()
types.ChannelAdminLogEventActionParticipantInvite.model_rebuild()
types.ChannelAdminLogEventActionParticipantToggleBan.model_rebuild()
types.ChannelAdminLogEventActionParticipantToggleAdmin.model_rebuild()
types.ChannelAdminLogEventActionChangeStickerSet.model_rebuild()
types.ChannelAdminLogEventActionTogglePreHistoryHidden.model_rebuild()
types.ChannelAdminLogEventActionDefaultBannedRights.model_rebuild()
types.ChannelAdminLogEventActionStopPoll.model_rebuild()
types.ChannelAdminLogEventActionChangeLinkedChat.model_rebuild()
types.ChannelAdminLogEventActionChangeLocation.model_rebuild()
types.ChannelAdminLogEventActionToggleSlowMode.model_rebuild()
types.ChannelAdminLogEventActionStartGroupCall.model_rebuild()
types.ChannelAdminLogEventActionDiscardGroupCall.model_rebuild()
types.ChannelAdminLogEventActionParticipantMute.model_rebuild()
types.ChannelAdminLogEventActionParticipantUnmute.model_rebuild()
types.ChannelAdminLogEventActionToggleGroupCallSetting.model_rebuild()
types.ChannelAdminLogEventActionParticipantJoinByInvite.model_rebuild()
types.ChannelAdminLogEventActionExportedInviteDelete.model_rebuild()
types.ChannelAdminLogEventActionExportedInviteRevoke.model_rebuild()
types.ChannelAdminLogEventActionExportedInviteEdit.model_rebuild()
types.ChannelAdminLogEventActionParticipantVolume.model_rebuild()
types.ChannelAdminLogEventActionChangeHistoryTTL.model_rebuild()
types.ChannelAdminLogEventActionParticipantJoinByRequest.model_rebuild()
types.ChannelAdminLogEventActionToggleNoForwards.model_rebuild()
types.ChannelAdminLogEventActionSendMessage.model_rebuild()
types.ChannelAdminLogEventActionChangeAvailableReactions.model_rebuild()
types.ChannelAdminLogEventActionChangeUsernames.model_rebuild()
types.ChannelAdminLogEventActionToggleForum.model_rebuild()
types.ChannelAdminLogEventActionCreateTopic.model_rebuild()
types.ChannelAdminLogEventActionEditTopic.model_rebuild()
types.ChannelAdminLogEventActionDeleteTopic.model_rebuild()
types.ChannelAdminLogEventActionPinTopic.model_rebuild()
types.ChannelAdminLogEventActionToggleAntiSpam.model_rebuild()
types.ChannelAdminLogEventActionChangePeerColor.model_rebuild()
types.ChannelAdminLogEventActionChangeProfilePeerColor.model_rebuild()
types.ChannelAdminLogEventActionChangeWallpaper.model_rebuild()
types.ChannelAdminLogEventActionChangeEmojiStatus.model_rebuild()
types.ChannelAdminLogEventActionChangeEmojiStickerSet.model_rebuild()
types.ChannelAdminLogEvent.model_rebuild()
types.ChannelAdminLogEventsFilter.model_rebuild()
types.PopularContact.model_rebuild()
types.RecentMeUrlUnknown.model_rebuild()
types.RecentMeUrlUser.model_rebuild()
types.RecentMeUrlChat.model_rebuild()
types.RecentMeUrlChatInvite.model_rebuild()
types.RecentMeUrlStickerSet.model_rebuild()
types.InputSingleMedia.model_rebuild()
types.WebAuthorization.model_rebuild()
types.InputMessageID.model_rebuild()
types.InputMessageReplyTo.model_rebuild()
types.InputMessagePinned.model_rebuild()
types.InputMessageCallbackQuery.model_rebuild()
types.InputDialogPeer.model_rebuild()
types.InputDialogPeerFolder.model_rebuild()
types.DialogPeer.model_rebuild()
types.DialogPeerFolder.model_rebuild()
types.FileHash.model_rebuild()
types.InputClientProxy.model_rebuild()
types.InputSecureFileUploaded.model_rebuild()
types.InputSecureFile.model_rebuild()
types.SecureFileEmpty.model_rebuild()
types.SecureFile.model_rebuild()
types.SecureData.model_rebuild()
types.SecurePlainPhone.model_rebuild()
types.SecurePlainEmail.model_rebuild()
types.SecureValueTypePersonalDetails.model_rebuild()
types.SecureValueTypePassport.model_rebuild()
types.SecureValueTypeDriverLicense.model_rebuild()
types.SecureValueTypeIdentityCard.model_rebuild()
types.SecureValueTypeInternalPassport.model_rebuild()
types.SecureValueTypeAddress.model_rebuild()
types.SecureValueTypeUtilityBill.model_rebuild()
types.SecureValueTypeBankStatement.model_rebuild()
types.SecureValueTypeRentalAgreement.model_rebuild()
types.SecureValueTypePassportRegistration.model_rebuild()
types.SecureValueTypeTemporaryRegistration.model_rebuild()
types.SecureValueTypePhone.model_rebuild()
types.SecureValueTypeEmail.model_rebuild()
types.SecureValue.model_rebuild()
types.InputSecureValue.model_rebuild()
types.SecureValueHash.model_rebuild()
types.SecureValueErrorData.model_rebuild()
types.SecureValueErrorFrontSide.model_rebuild()
types.SecureValueErrorReverseSide.model_rebuild()
types.SecureValueErrorSelfie.model_rebuild()
types.SecureValueErrorFile.model_rebuild()
types.SecureValueErrorFiles.model_rebuild()
types.SecureValueError.model_rebuild()
types.SecureValueErrorTranslationFile.model_rebuild()
types.SecureValueErrorTranslationFiles.model_rebuild()
types.SecureCredentialsEncrypted.model_rebuild()
types.SavedPhoneContact.model_rebuild()
types.PasswordKdfAlgoUnknown.model_rebuild()
types.PasswordKdfAlgoSHA256SHA256PBKDF2HMACSHA512iter100000SHA256ModPow.model_rebuild()
types.SecurePasswordKdfAlgoUnknown.model_rebuild()
types.SecurePasswordKdfAlgoPBKDF2HMACSHA512iter100000.model_rebuild()
types.SecurePasswordKdfAlgoSHA512.model_rebuild()
types.SecureSecretSettings.model_rebuild()
types.InputCheckPasswordEmpty.model_rebuild()
types.InputCheckPasswordSRP.model_rebuild()
types.SecureRequiredType.model_rebuild()
types.SecureRequiredTypeOneOf.model_rebuild()
types.InputAppEvent.model_rebuild()
types.JsonObjectValue.model_rebuild()
types.JsonNull.model_rebuild()
types.JsonBool.model_rebuild()
types.JsonNumber.model_rebuild()
types.JsonString.model_rebuild()
types.JsonArray.model_rebuild()
types.JsonObject.model_rebuild()
types.PageTableCell.model_rebuild()
types.PageTableRow.model_rebuild()
types.PageCaption.model_rebuild()
types.PageListItemText.model_rebuild()
types.PageListItemBlocks.model_rebuild()
types.PageListOrderedItemText.model_rebuild()
types.PageListOrderedItemBlocks.model_rebuild()
types.PageRelatedArticle.model_rebuild()
types.Page.model_rebuild()
types.PollAnswer.model_rebuild()
types.Poll.model_rebuild()
types.PollAnswerVoters.model_rebuild()
types.PollResults.model_rebuild()
types.ChatOnlines.model_rebuild()
types.StatsURL.model_rebuild()
types.ChatAdminRights.model_rebuild()
types.ChatBannedRights.model_rebuild()
types.InputWallPaper.model_rebuild()
types.InputWallPaperSlug.model_rebuild()
types.InputWallPaperNoFile.model_rebuild()
types.CodeSettings.model_rebuild()
types.WallPaperSettings.model_rebuild()
types.AutoDownloadSettings.model_rebuild()
types.EmojiKeyword.model_rebuild()
types.EmojiKeywordDeleted.model_rebuild()
types.EmojiKeywordsDifference.model_rebuild()
types.EmojiURL.model_rebuild()
types.EmojiLanguage.model_rebuild()
types.Folder.model_rebuild()
types.InputFolderPeer.model_rebuild()
types.FolderPeer.model_rebuild()
types.UrlAuthResultRequest.model_rebuild()
types.UrlAuthResultAccepted.model_rebuild()
types.UrlAuthResultDefault.model_rebuild()
types.ChannelLocationEmpty.model_rebuild()
types.ChannelLocation.model_rebuild()
types.PeerLocated.model_rebuild()
types.PeerSelfLocated.model_rebuild()
types.RestrictionReason.model_rebuild()
types.InputTheme.model_rebuild()
types.InputThemeSlug.model_rebuild()
types.Theme.model_rebuild()
types.BaseThemeClassic.model_rebuild()
types.BaseThemeDay.model_rebuild()
types.BaseThemeNight.model_rebuild()
types.BaseThemeTinted.model_rebuild()
types.BaseThemeArctic.model_rebuild()
types.InputThemeSettings.model_rebuild()
types.ThemeSettings.model_rebuild()
types.WebPageAttributeTheme.model_rebuild()
types.WebPageAttributeStory.model_rebuild()
types.WebPageAttributeStickerSet.model_rebuild()
types.BankCardOpenUrl.model_rebuild()
types.DialogFilter.model_rebuild()
types.DialogFilterDefault.model_rebuild()
types.DialogFilterChatlist.model_rebuild()
types.DialogFilterSuggested.model_rebuild()
types.StatsDateRangeDays.model_rebuild()
types.StatsAbsValueAndPrev.model_rebuild()
types.StatsPercentValue.model_rebuild()
types.StatsGraphAsync.model_rebuild()
types.StatsGraphError.model_rebuild()
types.StatsGraph.model_rebuild()
types.VideoSize.model_rebuild()
types.VideoSizeEmojiMarkup.model_rebuild()
types.VideoSizeStickerMarkup.model_rebuild()
types.StatsGroupTopPoster.model_rebuild()
types.StatsGroupTopAdmin.model_rebuild()
types.StatsGroupTopInviter.model_rebuild()
types.GlobalPrivacySettings.model_rebuild()
types.MessageViews.model_rebuild()
types.MessageReplyHeader.model_rebuild()
types.MessageReplyStoryHeader.model_rebuild()
types.MessageReplies.model_rebuild()
types.PeerBlocked.model_rebuild()
types.GroupCallDiscarded.model_rebuild()
types.GroupCall.model_rebuild()
types.InputGroupCall.model_rebuild()
types.GroupCallParticipant.model_rebuild()
types.InlineQueryPeerTypeSameBotPM.model_rebuild()
types.InlineQueryPeerTypePM.model_rebuild()
types.InlineQueryPeerTypeChat.model_rebuild()
types.InlineQueryPeerTypeMegagroup.model_rebuild()
types.InlineQueryPeerTypeBroadcast.model_rebuild()
types.InlineQueryPeerTypeBotPM.model_rebuild()
types.ChatInviteImporter.model_rebuild()
types.ChatAdminWithInvites.model_rebuild()
types.GroupCallParticipantVideoSourceGroup.model_rebuild()
types.GroupCallParticipantVideo.model_rebuild()
types.BotCommandScopeDefault.model_rebuild()
types.BotCommandScopeUsers.model_rebuild()
types.BotCommandScopeChats.model_rebuild()
types.BotCommandScopeChatAdmins.model_rebuild()
types.BotCommandScopePeer.model_rebuild()
types.BotCommandScopePeerAdmins.model_rebuild()
types.BotCommandScopePeerUser.model_rebuild()
types.SponsoredMessage.model_rebuild()
types.SearchResultsCalendarPeriod.model_rebuild()
types.SearchResultPosition.model_rebuild()
types.ReactionCount.model_rebuild()
types.MessageReactions.model_rebuild()
types.AvailableReaction.model_rebuild()
types.MessagePeerReaction.model_rebuild()
types.GroupCallStreamChannel.model_rebuild()
types.AttachMenuBotIconColor.model_rebuild()
types.AttachMenuBotIcon.model_rebuild()
types.AttachMenuBot.model_rebuild()
types.AttachMenuBotsNotModified.model_rebuild()
types.AttachMenuBots.model_rebuild()
types.AttachMenuBotsBot.model_rebuild()
types.WebViewResultUrl.model_rebuild()
types.SimpleWebViewResultUrl.model_rebuild()
types.WebViewMessageSent.model_rebuild()
types.BotMenuButtonDefault.model_rebuild()
types.BotMenuButtonCommands.model_rebuild()
types.BotMenuButton.model_rebuild()
types.NotificationSoundDefault.model_rebuild()
types.NotificationSoundNone.model_rebuild()
types.NotificationSoundLocal.model_rebuild()
types.NotificationSoundRingtone.model_rebuild()
types.AttachMenuPeerTypeSameBotPM.model_rebuild()
types.AttachMenuPeerTypeBotPM.model_rebuild()
types.AttachMenuPeerTypePM.model_rebuild()
types.AttachMenuPeerTypeChat.model_rebuild()
types.AttachMenuPeerTypeBroadcast.model_rebuild()
types.InputInvoiceMessage.model_rebuild()
types.InputInvoiceSlug.model_rebuild()
types.InputInvoicePremiumGiftCode.model_rebuild()
types.InputInvoiceStars.model_rebuild()
types.InputStorePaymentPremiumSubscription.model_rebuild()
types.InputStorePaymentGiftPremium.model_rebuild()
types.InputStorePaymentPremiumGiftCode.model_rebuild()
types.InputStorePaymentPremiumGiveaway.model_rebuild()
types.InputStorePaymentStars.model_rebuild()
types.PremiumGiftOption.model_rebuild()
types.PaymentFormMethod.model_rebuild()
types.EmojiStatusEmpty.model_rebuild()
types.EmojiStatus.model_rebuild()
types.EmojiStatusUntil.model_rebuild()
types.ReactionEmpty.model_rebuild()
types.ReactionEmoji.model_rebuild()
types.ReactionCustomEmoji.model_rebuild()
types.ChatReactionsNone.model_rebuild()
types.ChatReactionsAll.model_rebuild()
types.ChatReactionsSome.model_rebuild()
types.EmailVerifyPurposeLoginSetup.model_rebuild()
types.EmailVerifyPurposeLoginChange.model_rebuild()
types.EmailVerifyPurposePassport.model_rebuild()
types.EmailVerificationCode.model_rebuild()
types.EmailVerificationGoogle.model_rebuild()
types.EmailVerificationApple.model_rebuild()
types.PremiumSubscriptionOption.model_rebuild()
types.SendAsPeer.model_rebuild()
types.MessageExtendedMediaPreview.model_rebuild()
types.MessageExtendedMedia.model_rebuild()
types.StickerKeyword.model_rebuild()
types.Username.model_rebuild()
types.ForumTopicDeleted.model_rebuild()
types.ForumTopic.model_rebuild()
types.DefaultHistoryTTL.model_rebuild()
types.ExportedContactToken.model_rebuild()
types.RequestPeerTypeUser.model_rebuild()
types.RequestPeerTypeChat.model_rebuild()
types.RequestPeerTypeBroadcast.model_rebuild()
types.EmojiListNotModified.model_rebuild()
types.EmojiList.model_rebuild()
types.EmojiGroup.model_rebuild()
types.EmojiGroupGreeting.model_rebuild()
types.EmojiGroupPremium.model_rebuild()
types.TextWithEntities.model_rebuild()
types.AutoSaveSettings.model_rebuild()
types.AutoSaveException.model_rebuild()
types.InputBotAppID.model_rebuild()
types.InputBotAppShortName.model_rebuild()
types.BotAppNotModified.model_rebuild()
types.BotApp.model_rebuild()
types.AppWebViewResultUrl.model_rebuild()
types.InlineBotWebView.model_rebuild()
types.ReadParticipantDate.model_rebuild()
types.InputChatlistDialogFilter.model_rebuild()
types.ExportedChatlistInvite.model_rebuild()
types.MessagePeerVote.model_rebuild()
types.MessagePeerVoteInputOption.model_rebuild()
types.MessagePeerVoteMultiple.model_rebuild()
types.StoryViews.model_rebuild()
types.StoryItemDeleted.model_rebuild()
types.StoryItemSkipped.model_rebuild()
types.StoryItem.model_rebuild()
types.StoryView.model_rebuild()
types.StoryViewPublicForward.model_rebuild()
types.StoryViewPublicRepost.model_rebuild()
types.InputReplyToMessage.model_rebuild()
types.InputReplyToStory.model_rebuild()
types.ExportedStoryLink.model_rebuild()
types.StoriesStealthMode.model_rebuild()
types.MediaAreaCoordinates.model_rebuild()
types.MediaAreaVenue.model_rebuild()
types.InputMediaAreaVenue.model_rebuild()
types.MediaAreaGeoPoint.model_rebuild()
types.MediaAreaSuggestedReaction.model_rebuild()
types.MediaAreaChannelPost.model_rebuild()
types.InputMediaAreaChannelPost.model_rebuild()
types.PeerStories.model_rebuild()
types.PremiumGiftCodeOption.model_rebuild()
types.PrepaidGiveaway.model_rebuild()
types.Boost.model_rebuild()
types.MyBoost.model_rebuild()
types.StoryFwdHeader.model_rebuild()
types.PostInteractionCountersMessage.model_rebuild()
types.PostInteractionCountersStory.model_rebuild()
types.PublicForwardMessage.model_rebuild()
types.PublicForwardStory.model_rebuild()
types.PeerColor.model_rebuild()
types.StoryReaction.model_rebuild()
types.StoryReactionPublicForward.model_rebuild()
types.StoryReactionPublicRepost.model_rebuild()
types.SavedDialog.model_rebuild()
types.SavedReactionTag.model_rebuild()
types.OutboxReadDate.model_rebuild()
types.SmsJob.model_rebuild()
types.BusinessWeeklyOpen.model_rebuild()
types.BusinessWorkHours.model_rebuild()
types.BusinessLocation.model_rebuild()
types.InputBusinessRecipients.model_rebuild()
types.BusinessRecipients.model_rebuild()
types.BusinessAwayMessageScheduleAlways.model_rebuild()
types.BusinessAwayMessageScheduleOutsideWorkHours.model_rebuild()
types.BusinessAwayMessageScheduleCustom.model_rebuild()
types.InputBusinessGreetingMessage.model_rebuild()
types.BusinessGreetingMessage.model_rebuild()
types.InputBusinessAwayMessage.model_rebuild()
types.BusinessAwayMessage.model_rebuild()
types.Timezone.model_rebuild()
types.QuickReply.model_rebuild()
types.InputQuickReplyShortcut.model_rebuild()
types.InputQuickReplyShortcutId.model_rebuild()
types.ConnectedBot.model_rebuild()
types.Birthday.model_rebuild()
types.BotBusinessConnection.model_rebuild()
types.InputBusinessIntro.model_rebuild()
types.BusinessIntro.model_rebuild()
types.InputCollectibleUsername.model_rebuild()
types.InputCollectiblePhone.model_rebuild()
types.InputBusinessBotRecipients.model_rebuild()
types.BusinessBotRecipients.model_rebuild()
types.ContactBirthday.model_rebuild()
types.MissingInvitee.model_rebuild()
types.InputBusinessChatLink.model_rebuild()
types.BusinessChatLink.model_rebuild()
types.RequestedPeerUser.model_rebuild()
types.RequestedPeerChat.model_rebuild()
types.RequestedPeerChannel.model_rebuild()
types.SponsoredMessageReportOption.model_rebuild()
types.BroadcastRevenueTransactionProceeds.model_rebuild()
types.BroadcastRevenueTransactionWithdrawal.model_rebuild()
types.BroadcastRevenueTransactionRefund.model_rebuild()
types.ReactionNotificationsFromContacts.model_rebuild()
types.ReactionNotificationsFromAll.model_rebuild()
types.ReactionsNotifySettings.model_rebuild()
types.BroadcastRevenueBalances.model_rebuild()
types.AvailableEffect.model_rebuild()
types.FactCheck.model_rebuild()
types.StarsTransactionPeerUnsupported.model_rebuild()
types.StarsTransactionPeerAppStore.model_rebuild()
types.StarsTransactionPeerPlayMarket.model_rebuild()
types.StarsTransactionPeerPremiumBot.model_rebuild()
types.StarsTransactionPeerFragment.model_rebuild()
types.StarsTransactionPeer.model_rebuild()
types.StarsTopupOption.model_rebuild()
types.StarsTransaction.model_rebuild()
types.storage.FileUnknown.model_rebuild()
types.storage.FilePartial.model_rebuild()
types.storage.FileJpeg.model_rebuild()
types.storage.FileGif.model_rebuild()
types.storage.FilePng.model_rebuild()
types.storage.FilePdf.model_rebuild()
types.storage.FileMp3.model_rebuild()
types.storage.FileMov.model_rebuild()
types.storage.FileMp4.model_rebuild()
types.storage.FileWebp.model_rebuild()
types.auth.SentCode.model_rebuild()
types.auth.SentCodeSuccess.model_rebuild()
types.auth.Authorization.model_rebuild()
types.auth.AuthorizationSignUpRequired.model_rebuild()
types.auth.ExportedAuthorization.model_rebuild()
types.auth.PasswordRecovery.model_rebuild()
types.auth.CodeTypeSms.model_rebuild()
types.auth.CodeTypeCall.model_rebuild()
types.auth.CodeTypeFlashCall.model_rebuild()
types.auth.CodeTypeMissedCall.model_rebuild()
types.auth.CodeTypeFragmentSms.model_rebuild()
types.auth.SentCodeTypeApp.model_rebuild()
types.auth.SentCodeTypeSms.model_rebuild()
types.auth.SentCodeTypeCall.model_rebuild()
types.auth.SentCodeTypeFlashCall.model_rebuild()
types.auth.SentCodeTypeMissedCall.model_rebuild()
types.auth.SentCodeTypeEmailCode.model_rebuild()
types.auth.SentCodeTypeSetUpEmailRequired.model_rebuild()
types.auth.SentCodeTypeFragmentSms.model_rebuild()
types.auth.SentCodeTypeFirebaseSms.model_rebuild()
types.auth.SentCodeTypeSmsWord.model_rebuild()
types.auth.SentCodeTypeSmsPhrase.model_rebuild()
types.auth.LoginToken.model_rebuild()
types.auth.LoginTokenMigrateTo.model_rebuild()
types.auth.LoginTokenSuccess.model_rebuild()
types.auth.LoggedOut.model_rebuild()
types.contacts.ContactsNotModified.model_rebuild()
types.contacts.Contacts.model_rebuild()
types.contacts.ImportedContacts.model_rebuild()
types.contacts.Blocked.model_rebuild()
types.contacts.BlockedSlice.model_rebuild()
types.contacts.Found.model_rebuild()
types.contacts.ResolvedPeer.model_rebuild()
types.contacts.TopPeersNotModified.model_rebuild()
types.contacts.TopPeers.model_rebuild()
types.contacts.TopPeersDisabled.model_rebuild()
types.contacts.ContactBirthdays.model_rebuild()
types.messages.Dialogs.model_rebuild()
types.messages.DialogsSlice.model_rebuild()
types.messages.DialogsNotModified.model_rebuild()
types.messages.Messages.model_rebuild()
types.messages.MessagesSlice.model_rebuild()
types.messages.ChannelMessages.model_rebuild()
types.messages.MessagesNotModified.model_rebuild()
types.messages.Chats.model_rebuild()
types.messages.ChatsSlice.model_rebuild()
types.messages.ChatFull.model_rebuild()
types.messages.AffectedHistory.model_rebuild()
types.messages.DhConfigNotModified.model_rebuild()
types.messages.DhConfig.model_rebuild()
types.messages.SentEncryptedMessage.model_rebuild()
types.messages.SentEncryptedFile.model_rebuild()
types.messages.StickersNotModified.model_rebuild()
types.messages.Stickers.model_rebuild()
types.messages.AllStickersNotModified.model_rebuild()
types.messages.AllStickers.model_rebuild()
types.messages.AffectedMessages.model_rebuild()
types.messages.StickerSet.model_rebuild()
types.messages.StickerSetNotModified.model_rebuild()
types.messages.SavedGifsNotModified.model_rebuild()
types.messages.SavedGifs.model_rebuild()
types.messages.BotResults.model_rebuild()
types.messages.BotCallbackAnswer.model_rebuild()
types.messages.MessageEditData.model_rebuild()
types.messages.PeerDialogs.model_rebuild()
types.messages.FeaturedStickersNotModified.model_rebuild()
types.messages.FeaturedStickers.model_rebuild()
types.messages.RecentStickersNotModified.model_rebuild()
types.messages.RecentStickers.model_rebuild()
types.messages.ArchivedStickers.model_rebuild()
types.messages.StickerSetInstallResultSuccess.model_rebuild()
types.messages.StickerSetInstallResultArchive.model_rebuild()
types.messages.HighScores.model_rebuild()
types.messages.FavedStickersNotModified.model_rebuild()
types.messages.FavedStickers.model_rebuild()
types.messages.FoundStickerSetsNotModified.model_rebuild()
types.messages.FoundStickerSets.model_rebuild()
types.messages.SearchCounter.model_rebuild()
types.messages.InactiveChats.model_rebuild()
types.messages.VotesList.model_rebuild()
types.messages.MessageViews.model_rebuild()
types.messages.DiscussionMessage.model_rebuild()
types.messages.HistoryImport.model_rebuild()
types.messages.HistoryImportParsed.model_rebuild()
types.messages.AffectedFoundMessages.model_rebuild()
types.messages.ExportedChatInvites.model_rebuild()
types.messages.ExportedChatInvite.model_rebuild()
types.messages.ExportedChatInviteReplaced.model_rebuild()
types.messages.ChatInviteImporters.model_rebuild()
types.messages.ChatAdminsWithInvites.model_rebuild()
types.messages.CheckedHistoryImportPeer.model_rebuild()
types.messages.SponsoredMessages.model_rebuild()
types.messages.SponsoredMessagesEmpty.model_rebuild()
types.messages.SearchResultsCalendar.model_rebuild()
types.messages.SearchResultsPositions.model_rebuild()
types.messages.PeerSettings.model_rebuild()
types.messages.MessageReactionsList.model_rebuild()
types.messages.AvailableReactionsNotModified.model_rebuild()
types.messages.AvailableReactions.model_rebuild()
types.messages.TranscribedAudio.model_rebuild()
types.messages.ReactionsNotModified.model_rebuild()
types.messages.Reactions.model_rebuild()
types.messages.ForumTopics.model_rebuild()
types.messages.EmojiGroupsNotModified.model_rebuild()
types.messages.EmojiGroups.model_rebuild()
types.messages.TranslateResult.model_rebuild()
types.messages.BotApp.model_rebuild()
types.messages.WebPage.model_rebuild()
types.messages.SavedDialogs.model_rebuild()
types.messages.SavedDialogsSlice.model_rebuild()
types.messages.SavedDialogsNotModified.model_rebuild()
types.messages.SavedReactionTagsNotModified.model_rebuild()
types.messages.SavedReactionTags.model_rebuild()
types.messages.QuickReplies.model_rebuild()
types.messages.QuickRepliesNotModified.model_rebuild()
types.messages.DialogFilters.model_rebuild()
types.messages.MyStickers.model_rebuild()
types.messages.InvitedUsers.model_rebuild()
types.messages.AvailableEffectsNotModified.model_rebuild()
types.messages.AvailableEffects.model_rebuild()
types.updates.State.model_rebuild()
types.updates.DifferenceEmpty.model_rebuild()
types.updates.Difference.model_rebuild()
types.updates.DifferenceSlice.model_rebuild()
types.updates.DifferenceTooLong.model_rebuild()
types.updates.ChannelDifferenceEmpty.model_rebuild()
types.updates.ChannelDifferenceTooLong.model_rebuild()
types.updates.ChannelDifference.model_rebuild()
types.photos.Photos.model_rebuild()
types.photos.PhotosSlice.model_rebuild()
types.photos.Photo.model_rebuild()
types.upload.File.model_rebuild()
types.upload.FileCdnRedirect.model_rebuild()
types.upload.WebFile.model_rebuild()
types.upload.CdnFileReuploadNeeded.model_rebuild()
types.upload.CdnFile.model_rebuild()
types.help.AppUpdate.model_rebuild()
types.help.NoAppUpdate.model_rebuild()
types.help.InviteText.model_rebuild()
types.help.Support.model_rebuild()
types.help.TermsOfService.model_rebuild()
types.help.RecentMeUrls.model_rebuild()
types.help.TermsOfServiceUpdateEmpty.model_rebuild()
types.help.TermsOfServiceUpdate.model_rebuild()
types.help.DeepLinkInfoEmpty.model_rebuild()
types.help.DeepLinkInfo.model_rebuild()
types.help.PassportConfigNotModified.model_rebuild()
types.help.PassportConfig.model_rebuild()
types.help.SupportName.model_rebuild()
types.help.UserInfoEmpty.model_rebuild()
types.help.UserInfo.model_rebuild()
types.help.PromoDataEmpty.model_rebuild()
types.help.PromoData.model_rebuild()
types.help.CountryCode.model_rebuild()
types.help.Country.model_rebuild()
types.help.CountriesListNotModified.model_rebuild()
types.help.CountriesList.model_rebuild()
types.help.PremiumPromo.model_rebuild()
types.help.AppConfigNotModified.model_rebuild()
types.help.AppConfig.model_rebuild()
types.help.PeerColorSet.model_rebuild()
types.help.PeerColorProfileSet.model_rebuild()
types.help.PeerColorOption.model_rebuild()
types.help.PeerColorsNotModified.model_rebuild()
types.help.PeerColors.model_rebuild()
types.help.TimezonesListNotModified.model_rebuild()
types.help.TimezonesList.model_rebuild()
types.account.PrivacyRules.model_rebuild()
types.account.Authorizations.model_rebuild()
types.account.Password.model_rebuild()
types.account.PasswordSettings.model_rebuild()
types.account.PasswordInputSettings.model_rebuild()
types.account.TmpPassword.model_rebuild()
types.account.WebAuthorizations.model_rebuild()
types.account.AuthorizationForm.model_rebuild()
types.account.SentEmailCode.model_rebuild()
types.account.Takeout.model_rebuild()
types.account.WallPapersNotModified.model_rebuild()
types.account.WallPapers.model_rebuild()
types.account.AutoDownloadSettings.model_rebuild()
types.account.ThemesNotModified.model_rebuild()
types.account.Themes.model_rebuild()
types.account.ContentSettings.model_rebuild()
types.account.ResetPasswordFailedWait.model_rebuild()
types.account.ResetPasswordRequestedWait.model_rebuild()
types.account.ResetPasswordOk.model_rebuild()
types.account.SavedRingtonesNotModified.model_rebuild()
types.account.SavedRingtones.model_rebuild()
types.account.SavedRingtone.model_rebuild()
types.account.SavedRingtoneConverted.model_rebuild()
types.account.EmojiStatusesNotModified.model_rebuild()
types.account.EmojiStatuses.model_rebuild()
types.account.EmailVerified.model_rebuild()
types.account.EmailVerifiedLogin.model_rebuild()
types.account.AutoSaveSettings.model_rebuild()
types.account.ConnectedBots.model_rebuild()
types.account.BusinessChatLinks.model_rebuild()
types.account.ResolvedBusinessChatLinks.model_rebuild()
types.channels.ChannelParticipants.model_rebuild()
types.channels.ChannelParticipantsNotModified.model_rebuild()
types.channels.ChannelParticipant.model_rebuild()
types.channels.AdminLogResults.model_rebuild()
types.channels.SendAsPeers.model_rebuild()
types.channels.SponsoredMessageReportResultChooseOption.model_rebuild()
types.channels.SponsoredMessageReportResultAdsHidden.model_rebuild()
types.channels.SponsoredMessageReportResultReported.model_rebuild()
types.payments.PaymentForm.model_rebuild()
types.payments.PaymentFormStars.model_rebuild()
types.payments.ValidatedRequestedInfo.model_rebuild()
types.payments.PaymentResult.model_rebuild()
types.payments.PaymentVerificationNeeded.model_rebuild()
types.payments.PaymentReceipt.model_rebuild()
types.payments.PaymentReceiptStars.model_rebuild()
types.payments.SavedInfo.model_rebuild()
types.payments.BankCardData.model_rebuild()
types.payments.ExportedInvoice.model_rebuild()
types.payments.CheckedGiftCode.model_rebuild()
types.payments.GiveawayInfo.model_rebuild()
types.payments.GiveawayInfoResults.model_rebuild()
types.payments.StarsStatus.model_rebuild()
types.phone.PhoneCall.model_rebuild()
types.phone.GroupCall.model_rebuild()
types.phone.GroupParticipants.model_rebuild()
types.phone.JoinAsPeers.model_rebuild()
types.phone.ExportedGroupCallInvite.model_rebuild()
types.phone.GroupCallStreamChannels.model_rebuild()
types.phone.GroupCallStreamRtmpUrl.model_rebuild()
types.stats.BroadcastStats.model_rebuild()
types.stats.MegagroupStats.model_rebuild()
types.stats.MessageStats.model_rebuild()
types.stats.StoryStats.model_rebuild()
types.stats.PublicForwards.model_rebuild()
types.stats.BroadcastRevenueStats.model_rebuild()
types.stats.BroadcastRevenueWithdrawalUrl.model_rebuild()
types.stats.BroadcastRevenueTransactions.model_rebuild()
types.stickers.SuggestedShortName.model_rebuild()
types.users.UserFull.model_rebuild()
types.chatlists.ExportedChatlistInvite.model_rebuild()
types.chatlists.ExportedInvites.model_rebuild()
types.chatlists.ChatlistInviteAlready.model_rebuild()
types.chatlists.ChatlistInvite.model_rebuild()
types.chatlists.ChatlistUpdates.model_rebuild()
types.bots.BotInfo.model_rebuild()
types.stories.AllStoriesNotModified.model_rebuild()
types.stories.AllStories.model_rebuild()
types.stories.Stories.model_rebuild()
types.stories.StoryViewsList.model_rebuild()
types.stories.StoryViews.model_rebuild()
types.stories.PeerStories.model_rebuild()
types.stories.StoryReactionsList.model_rebuild()
types.premium.BoostsList.model_rebuild()
types.premium.MyBoosts.model_rebuild()
types.premium.BoostsStatus.model_rebuild()
types.smsjobs.EligibleToJoin.model_rebuild()
types.smsjobs.Status.model_rebuild()
types.fragment.CollectibleInfo.model_rebuild()
